History — Meta Package Manager 2.3.0 documentation

# History

The `package_manager.py` script started its life in my ‘dotfile’ repository, as a rewrite from Bash to Python of the ‘brew-updates.sh’ script.

I then merged both Homebrew and Cask upgrade in the same single script as both were competing with each other when run concurrently.

I finally proposed the script for inclusion in the official BitBar plugin repository. It lived there for a couple of weeks and saw a huge amount of contributions by the community.

With its complexity increasing, it was decided to move the plugin to its own repository. For details, see the migration script.